StandardRuntimeServices

Struct StandardRuntimeServices 

pub struct StandardRuntimeServices<'a> { /* private fields */ }
The UEFI spec runtime services. It wraps an AtomicPtr around efi::RuntimeServices

UEFI Spec Documentation: 8. Services - RuntimeServices

Implementations

Source

impl<'a> StandardRuntimeServices<'a>

pub const fn new(efi_runtime_services: &'a RuntimeServices) -> Self

Create a new StandardRuntimeServices with the provided efi::RuntimeServices.

pub const fn new_uninit() -> Self

Create a new StandardRuntimeServices that is uninitialized. The struct need to be initialize later with Self::initialize, otherwise, subsequent call will panic.

pub fn initialize(&'a self, efi_runtime_services: &'a RuntimeServices)

Initialize the StandardRuntimeServices with a reference to efi::RuntimeServices.

Debug asserts

This function will assert on debug if already initialized.