pub struct VariableInfo {
pub maximum_variable_storage_size: u64,
pub remaining_variable_storage_size: u64,
pub maximum_variable_size: u64,
}Expand description
Variable information returned by RuntimeServices::query_variable_info
Fields
maximum_variable_storage_size: u64The maximum size of the storage space available for the EFI variables associated with the attributes specified
remaining_variable_storage_size: u64The remaining size of the storage space available for EFI variables associated with the attributes specified
maximum_variable_size: u64Trait Implementations