VariableNameIterator

Struct VariableNameIterator 

pub struct VariableNameIterator<'a, R: RuntimeServices> { /* private fields */ }
Provides a FallibleStreamingIterator over UEFI variable names

Produces an EFI status on error.

Examples

Iterating through all UEFI variable names

pub static RUNTIME_SERVICES: StandardRuntimeServices =
    StandardRuntimeServices::new(&(*runtime_services_ptr));
let mut iter = VariableNameIterator::new_from_first(runtime_services);
while let Some(variable_identifier) = iter.next()? {
    some_function(variable_identifier.name, variable_identifier.namespace);
}

Iterating through UEFI variable names, starting with a known one

let mut iter = VariableNameIterator::new_from_variable(
    &SOME_VARIABLE_NAME,
    &SOME_VARIABLE_NAMESPACE,
    runtime_services
);

while let Some(variable_identifier) = iter.next()? {
    some_function(variable_identifier.name, variable_identifier.namespace);
}

Implementations

Source

impl<'a, R: RuntimeServices> VariableNameIterator<'a, R>

pub fn new_from_first(runtime_services: &'a R) -> Self

Produce a new iterator from the beginning of the UEFI variable list

pub fn new_from_variable( name: &[u16], namespace: &Guid, runtime_services: &'a R, ) -> Self

Produce a new iterator, starting from a given variable