pub struct StandardRuntimeServices<'a> { /* private fields */ }Expand description
The UEFI spec runtime services.
It wraps an AtomicPtr around efi::RuntimeServices
UEFI Spec Documentation: 8. Services - RuntimeServices
Implementations
Sourceimpl<'a> StandardRuntimeServices<'a>
impl<'a> StandardRuntimeServices<'a>
Sourcepub const fn new(efi_runtime_services: &'a RuntimeServices) -> Self
pub const fn new(efi_runtime_services: &'a RuntimeServices) -> Self
Create a new StandardRuntimeServices with the provided efi::RuntimeServices.
Sourcepub const fn new_uninit() -> Self
pub const fn new_uninit() -> Self
Create a new StandardRuntimeServices that is uninitialized. The struct need to be initialize later with Self::initialize, otherwise, subsequent call will panic.
Sourcepub fn initialize(&'a self, efi_runtime_services: &'a RuntimeServices)
pub fn initialize(&'a self, efi_runtime_services: &'a RuntimeServices)
Initialize the StandardRuntimeServices with a reference to efi::RuntimeServices.
Debug asserts
This function will assert on debug if already initialized.